﻿//****************************************************************
//
// Gimp XCF Content Pipeline Importer
//
// Written by: Louis Ingenthron
// Last Modified: 28.05.2009
//
//****************************************************************

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;

namespace XCFProcessorLib
{
    public static class ExtensionMethods
    {
        /// <summary>
        /// Reverses the byte order of an int
        /// </summary>
        /// <param name="val"></param>
        /// <returns></returns>
        public static int ReverseEndianness(this int val)
        {
            byte[] b = BitConverter.GetBytes(val);
            Array.Reverse(b);
            return BitConverter.ToInt32(b,0);
        }

        /// <summary>
        /// Reverses the byte order of a uint
        /// </summary>
        /// <param name="val"></param>
        /// <returns></returns>
        public static uint ReverseEndianness(this uint val)
        {
            byte[] b = BitConverter.GetBytes(val);
            Array.Reverse(b);
            return BitConverter.ToUInt32(b,0);
        }

        /// <summary>
        /// Reverses the byte order of a float
        /// </summary>
        /// <param name="val"></param>
        /// <returns></returns>
        public static float ReverseEndianness(this float val)
        {
            byte[] b = BitConverter.GetBytes(val);
            Array.Reverse(b);
            return BitConverter.ToSingle(b,0);
        }

        /// <summary>
        /// Reads a String with a prefixed length and null terminator
        /// (jeez that is redundant)
        /// </summary>
        /// <param name="bin">The Stream to read from</param>
        /// <returns>A String</returns>
        public static String ReadXCFString(this BinaryReader bin)
        {
            uint length = bin.ReadUInt32().ReverseEndianness();
            if (length > 0)
            {
                char[] ch = bin.ReadChars((int)length - 1);
                bin.ReadChar();
                return new String(ch);
            }
            else
                return "";
        }
    }
}
